@@ -18,6 +18,7 @@
 require 'gem2deb'
 require 'yaml'
 require 'gem2deb/metadata'
+require 'gem2deb/test_runner'
 require 'rubygems'
 require 'fileutils'
 require 'erb'
@@ -57,6 +58,8 @@ module Gem2Deb
 
     attr_accessor :do_wnpp_check
 
+    attr_accessor :extra_build_dependencies
+
     def initialize(input, options = {})
       initialize_from_options(options)
       if File.directory?(input)
@@ -64,6 +67,7 @@ module Gem2Deb
       else
         initialize_from_tarball(input)
       end
+      @extra_build_dependencies = []
     end
 
     def initialize_from_options(options)
@@ -140,9 +144,10 @@ module Gem2Deb
     def build_in_directory(directory)
       Dir.chdir(directory) do
         read_upstream_source_info
-        create_debian_boilerplates
+        FileUtils.mkdir_p('debian')
         other_files
         test_suite
+        create_debian_boilerplates
       end
     end
     
@@ -174,7 +179,7 @@ module Gem2Deb
     end
 
     def create_orig_tarball
-      if source_package_name != orig_tarball_name && !File.exists?(orig_tarball_name)
+      if source_package_name != orig_tarball_name && !File.exist?(orig_tarball_name)
         run('ln', '-s', source_tarball_name, orig_tarball_name)
       end
     end
@@ -184,7 +189,7 @@ module Gem2Deb
       if !File.directory?(gem_dirname)
         raise "Extracting did not create #{gem_dirname} directory."
       end
-      if gem_dirname != source_dirname && !File.exists?(source_dirname)
+      if gem_dirname != source_dirname && !File.exist?(source_dirname)
         FileUtils.mv gem_dirname, source_dirname
       end
     end
@@ -201,16 +206,22 @@ module Gem2Deb
       end
     end
 
+    def write_if_missing(filename)
+      unless File.exist? filename
+        File.open(filename, 'w') { |f| yield f }
+      end
+    end
+
     def create_debian_boilerplates
       FileUtils.mkdir_p('debian')
-      unless File.exists?('debian/changelog')
+      unless File.exist?('debian/changelog')
         run('dch', '--create', '--empty', '--package', source_package_name,
             '--newversion', "#{gem_version}-1",
             "Initial release (Closes: #{itp_bug})")
       end
       templates.each do |template|
         FileUtils.mkdir_p(template.directory)
-        File.open(template.filename, 'w') do |f|
+        write_if_missing(template.filename) do |f|
           f.puts ERB.new(template.data, nil, '<>').result(binding)
         end
       end
@@ -289,30 +300,58 @@ module Gem2Deb
     end
 
     def test_suite
+      if !Gem2Deb::TestRunner.detect_real_runner
+        test_suite_rspec or test_suite_yaml or test_suite_rb
+      end
+    end
+
+    def test_suite_rspec
+      if File::directory?("spec")
+        extra_build_dependencies << 'ruby-rspec' << 'rake'
+        write_if_missing("debian/ruby-tests.rake") do |f|
+          f.puts <<-EOF
+require 'rspec/core/rake_task'
+
+RSpec::Core::RakeTask.new(:spec) do |spec|
+  spec.pattern = './spec/*_spec.rb'
+end
+
+task :default => :spec
+        EOF
+        end
+        true
+      else
+        false
+      end
+    end
+
+
+    def test_suite_yaml
       if !metadata.test_files.empty?
-        File::open("debian/ruby-test-files.yaml", 'w') do |f|
+        write_if_missing("debian/ruby-test-files.yaml") do |f|
           YAML::dump(metadata.test_files, f)
         end
+        true
       else
-        if File::directory?("test") or File::directory?("spec")
-          File::open("debian/ruby-tests.rb", 'w') do |f|
-            f.puts <<-EOF
-# FIXME
-# there's a spec/ or a test/ directory in the upstream source, but
-# no test suite was defined in the Gem specification. It would be
-# a good idea to define it here so the package gets tested at build time.
-# Examples:
-# $: << 'lib' << '.'
-# Dir['{spec,test}/**/*.rb'].each { |f| require f }
-#
-# require 'test/ts_foo.rb'
-#
-# require 'rbconfig'
-# ruby = File.join(RbConfig::CONFIG['bindir'], RbConfig::CONFIG['ruby_install_name'])
-# exec("\#{ruby} -I. test/runtests.rb")
-            EOF
-          end
+        false
+      end
+    end
+
+    def test_suite_rb
+      if File::directory?("test")
+        extra_build_dependencies << 'rake'
+        write_if_missing("debian/ruby-tests.rake") do |f|
+          f.puts <<-EOF
+require 'gem2deb/rake/testtask'
+
+Gem2Deb::Rake::TestTask.new do |t|
+  t.test_files = FileList['test/*_test.rb']
+end
+        EOF
         end
+        true
+      else
+        false
       end
     end
 
@@ -335,7 +374,7 @@ module Gem2Deb
         docs << "# #{r}\n"
       end
       if docs != ""
-        File::open("debian/#{source_package_name}.docs", 'w') do |f|
+        write_if_missing("debian/#{source_package_name}.docs") do |f|
           f.puts docs
         end
       end
@@ -352,7 +391,7 @@ module Gem2Deb
         end
       end
       if examples != ""
-        File::open("debian/#{source_package_name}.examples", 'w') do |f|
+        write_if_missing("debian/#{source_package_name}.examples") do |f|
           f.puts examples
         end
       end
@@ -374,7 +413,7 @@ module Gem2Deb
         EOF
       end
       if installs != ""
-        File::open("debian/#{source_package_name}.install", 'w') do |f|
+        write_if_missing("debian/#{source_package_name}.install") do |f|
           f.puts installs
         end
       end
@@ -384,7 +423,7 @@ module Gem2Deb
         manpages = Dir.glob("man/**/*.[1-8]")
         manpages_header = "# FIXME: man/ dir found in source. Consider installing manpages"
 
-        File::open("debian/#{source_package_name}.manpages", 'w') do |f|
+        write_if_missing("debian/#{source_package_name}.manpages") do |f|
           f.puts manpages_header
           manpages.each do |m|
             f.puts "# " + m
