@@ -23,13 +23,9 @@ module Gem2Deb
 
     attr_accessor :autopkgtest
 
-    def initialize
-      self.autopkgtest = autopkgtest
-    end
-
     def load_path
       if self.autopkgtest
-        return []
+        return ['.']
       end
 
       # We should only use installation paths for the current Ruby
@@ -61,8 +57,13 @@ module Gem2Deb
       nil
     end
 
+    # override in subclasses if needed
+    def real_runner?
+      true
+    end
+
     def activate?
-      required_file && File.exists?(required_file)
+      required_file && File.exist?(required_file)
     end
 
     def run_ruby(*cmd)
@@ -87,13 +88,13 @@ module Gem2Deb
     end
 
     def move_away(dir)
-      if File.exists?(dir)
+      if File.exist?(dir)
         mv dir, '.gem2deb.' + dir
       end
     end
 
     def restore(dir)
-      if File.exists?('.gem2deb.' + dir)
+      if File.exist?('.gem2deb.' + dir)
         mv '.gem2deb.' + dir, dir
       end
     end
@@ -108,7 +109,15 @@ module Gem2Deb
     def self.detect
       subclasses.map(&:new).find do |runner|
         runner.activate?
-      end || bail("E: this tool must be run from inside a Debian source package.")
+      end
+    end
+    def self.detect!
+      detect || bail("E: this tool must be run from inside a Debian source package.")
+    end
+    def self.detect_real_runner
+      subclasses.map(&:new).find do |runner|
+        runner.real_runner? && runner.activate?
+      end
     end
     def self.bail(msg)
       puts msg
@@ -168,24 +177,11 @@ module Gem2Deb
       def run_tests
         puts "Running tests for #{rubyver}: found no way to run a test suite!"
       end
+      def real_runner?
+        false
+      end
     end
 
   end
 
 end
-
-if $PROGRAM_NAME == __FILE__
-  autopkgtest = false
-
-  if ARGV.length == 1 && ARGV.first == '--autopkgtest'
-    autopkgtest = true
-  elsif ARGV.length != 0
-    puts "usage: #{File.basename($PROGRAM_NAME)} [--autopkgtest]"
-    exit(1)
-  end
-
-  runner = Gem2Deb::TestRunner.detect
-  runner.autopkgtest = autopkgtest
-  runner.run_tests
-end
-
